Functions class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

Functions({Expr? database})
Functions.fromJson(Map<String, dynamic> json)
factory

Properties

database → Expr?
final
hashCode → int
The hash code for this object.
no setterinherited
id → String?
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
schema_ref → Expr?
finalinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited