Match class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

Match(Object index, {List? terms})
Match.fromJson(Map<String, dynamic> json)
factory

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → Object
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
terms → List?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited