Paginate class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

Paginate(Expr input, {DateTime? ts, int? size, Object before = CursorType.EMPTY, Object after = CursorType.EMPTY, bool? events, bool? sources})
Paginate.fromJson(Map<String, dynamic> json)
factory

Properties

after → Object
final
before → Object
final
events → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
input → Expr
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int?
final
sources → bool?
final
ts → DateTime?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited