ReplaceStrRegex class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

ReplaceStrRegex(Object value, Object pattern, Object replace, {Object? first_only})
ReplaceStrRegex.fromJson(Map<String, dynamic> json)
factory

Properties

first_only → Object?
final
hashCode → int
The hash code for this object.
no setterinherited
pattern → Object
final
replace → Object
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
value → Object
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited