Select class

Inheritance
Annotations
  • @JsonSerializable.new()

Constructors

Select(Object path, Expr from, {Object? default_})
Select.fromJson(Map<String, dynamic> json)
factory

Properties

default_ → Object?
final
from → Expr
final
hashCode → int
The hash code for this object.
no setterinherited
path → Object
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited